# Kant Framework
[![Build Status](https://travis-ci.org/patrickporto/kant.svg?branch=master)](https://travis-ci.org/patrickporto/kant)
[![codecov.io](https://codecov.io/github/patrickporto/kant/coverage.svg?branch=master)](https://codecov.io/github/patrickporto/kant?branch=master)


A CQRS and Event Sourcing framework for Python 3.

## Installing

```bash
pip install kant
```

## Getting started

> TODO

## Features

* Optimistic Concurrency


## Contributing

Please, read the contribute guide [CONTRIBUTING](CONTRIBUTING.md).

## License

**MIT**
